from common.logging_config import get_my_logger, DOCUMENTPATH

logger = get_my_logger("django")
